@@ -209,7 +209,7 @@ impl AnnisRunner {
                 "use_parallel" => self.use_parallel(&args),
                 "use_disk" => self.use_disk(&args),
                 "quirks_mode" => self.quirks_mode(&args),
-                "info" => self.info(),
+                "info" => self.info(&args),
                 "quit" | "exit" => return false,
                 _ => Err(anyhow!("unknown command \"{}\"", cmd).into()),
             };
@@ -235,29 +235,45 @@ impl AnnisRunner {
 
         // Determine most likely input format based on the extension of the file
         let path = PathBuf::from(args[0]);
-        let mut format = ImportFormat::RelANNIS;
+
         if path.is_file() {
             if let Some(file_ext) = path.extension() {
                 let file_ext = file_ext.to_string_lossy().to_lowercase();
-                if file_ext == "graphml" || file_ext == "xml" {
-                    format = ImportFormat::GraphML
-                } else if file_ext == "br" {
-                    format = ImportFormat::GraphMLCompressed
+
+                if file_ext == "zip" {
+                    // Import  ZIP file with possible multiple corpora
+                    let t_before = std::time::SystemTime::now();
+                    let names = self
+                        .storage
+                        .as_ref()
+                        .ok_or(anyhow!("No corpus storage location set"))?
+                        .import_all_from_zip(&path, self.use_disk)?;
+                    let load_time = t_before.elapsed();
+                    if let Ok(t) = load_time {
+                        info! {"imported corpora {:?} in {} ms", names, (t.as_secs() * 1000 + t.subsec_nanos() as u64 / 1_000_000)};
+                    }
+                } else {
+                    // Import a single corpus
+                    let mut format = ImportFormat::RelANNIS;
+
+                    if file_ext == "graphml" || file_ext == "xml" {
+                        format = ImportFormat::GraphML
+                    }
+
+                    let t_before = std::time::SystemTime::now();
+                    let name: String = self
+                        .storage
+                        .as_ref()
+                        .ok_or(anyhow!("No corpus storage location set"))?
+                        .import_from_fs(&path, format, overwritten_corpus_name, self.use_disk)?;
+                    let load_time = t_before.elapsed();
+                    if let Ok(t) = load_time {
+                        info! {"imported corpus {} in {} ms", name, (t.as_secs() * 1000 + t.subsec_nanos() as u64 / 1_000_000)};
+                    }
                 }
             }
         }
 
-        let t_before = std::time::SystemTime::now();
-        let name: String = self
-            .storage
-            .as_ref()
-            .ok_or(anyhow!("No corpus storage location set"))?
-            .import_from_fs(&path, format, overwritten_corpus_name, self.use_disk)?;
-        let load_time = t_before.elapsed();
-        if let Ok(t) = load_time {
-            info! {"imported corpus {} in {} ms", name, (t.as_secs() * 1000 + t.subsec_nanos() as u64 / 1_000_000)};
-        }
-
         Ok(())
     }
 
@@ -265,27 +281,31 @@ impl AnnisRunner {
         let args: Vec<&str> = args.split(' ').collect();
         if args.is_empty() {
             bail!("You need give the location of the output XML file as argument");
-        } else if self.current_corpus.len() != 1 {
-            bail!("You need to select a *single* corpus first with the \"corpus\" command");
         }
 
         let path = PathBuf::from(args[0]);
         let mut format = ExportFormat::GraphML;
         if let Some(file_ext) = path.extension() {
-            if file_ext.to_string_lossy() == "br" {
-                format = ExportFormat::GraphMLCompressed;
+            if file_ext.to_string_lossy().to_lowercase() == "zip" {
+                format = ExportFormat::GraphMLZip;
+            } else if file_ext.to_string_lossy() == ".graphml" && self.current_corpus.len() != 1 {
+                bail!(
+                    r##"You need to select a *single* corpus first with the \"corpus\" command when exporting to a GraphML file. 
+                To export multiple corpora, select a directory as output or a ZIP file (ending with .zip)"##
+                );
             }
+        } else {
+            format = ExportFormat::GraphMLDirectory;
         }
-        let corpus = &self.current_corpus[0];
 
         let t_before = std::time::SystemTime::now();
         self.storage
             .as_ref()
             .ok_or(anyhow!("No corpus storage location set"))?
-            .export_to_fs(corpus, &path, format)?;
+            .export_to_fs(&self.current_corpus, &path, format)?;
         let load_time = t_before.elapsed();
         if let Ok(t) = load_time {
-            info! {"exported corpus {} in {} ms", corpus, (t.as_secs() * 1000 + t.subsec_nanos() as u64 / 1_000_000)};
+            info! {"exported corpora {:?} in {} ms", &self.current_corpus, (t.as_secs() * 1000 + t.subsec_nanos() as u64 / 1_000_000)};
         }
 
         Ok(())
@@ -371,7 +391,7 @@ impl AnnisRunner {
         Ok(())
     }
 
-    fn info(&self) -> Result<()> {
+    fn info(&self, args: &str) -> Result<()> {
         if self.current_corpus.is_empty() {
             println!("You need to select a corpus for the \"info\" command");
         } else {
@@ -381,7 +401,11 @@ impl AnnisRunner {
                     .as_ref()
                     .ok_or(anyhow!("No corpus storage location set"))?
                     .info(corpus)?;
-                println!("{}", cinfo);
+                if args == "config" {
+                    println!("{}", toml::to_string(&cinfo.config)?);
+                } else {
+                    println!("{}", cinfo);
+                }
             }
         }
         Ok(())
@@ -652,7 +676,7 @@ fn main() {
     };
 
     let log_config = simplelog::ConfigBuilder::new()
-        .add_filter_ignore_str("rustyline:")
+        .add_filter_ignore_str("rustyline")
         .build();
 
     if let Err(e) = TermLogger::init(
